# /packages/sencha-filestorage/www/file-storage-treemodel.tcl
#
# Copyright (C) 2013 ]project-open[
#
# All rights reserved. Please check
# http://www.project-open.com/license/ for details.


# ---------------------------------------------------------------
# Page Contract
# ---------------------------------------------------------------

ad_page_contract {
    @author frank.bergmann@project-open.com
} {
    { package_key "file-storage" }
}

# ---------------------------------------------------------------
# Defaults & Security
# ---------------------------------------------------------------

set user_id [ad_maybe_redirect_for_registration]

set file_storage_package_id [db_string fs_pid "select package_id from apm_packages where package_key = :package_key"]
set file_storage_root_folder [fs::get_root_folder -package_id $file_storage_package_id]
set objects [fs::get_folder_objects -folder_id $file_storage_root_folder -user_id $user_id]

set names [list]
foreach o $objects {
    lappend names [fs::get_object_name -object_id $o]
}


set folder_sql "
	select	ci.item_id,
		ci.name,
		ci.content_type,
		tree_level(ci.tree_sortkey) as tree_level,
		cr.title,
		coalesce(cr.content_length, 0) as content_length,
		(select count(*) from cr_items child where child.parent_id = ci.item_id) as children
	from	cr_items folder,
		cr_items ci
		LEFT OUTER JOIN cr_revisions cr ON (ci.live_revision = cr.revision_id)
	where	folder.item_id = :file_storage_root_folder and
		ci.tree_sortkey between folder.tree_sortkey and tree_right(folder.tree_sortkey)
	order by ci.tree_sortkey
"

set items [join [db_list_of_lists asdf $folder_sql] "\n"]

set indent_space "        "
set min_level 2
set level $min_level
db_foreach folder_elements $folder_sql {

    set indent ""
    for {set i $min_level} {$i < $tree_level} {incr i} { append indent $indent_space }

    set done_p 0
    # Start a new 'children' list
    while {$tree_level > $level} {
	append result "${indent},children: \[\{\n"
	incr level
	set done_p 1
    }
    # Finish a list of a certain level
    while {$tree_level < $level} {
	append result "${indent}\}\]\n"
	incr level -1
	set done_p 1
    }
    if {!$done_p} {
	append result "${indent}\}, \{\n"
    }

    set leaf_json "expanded:true"
    set icon "task-folder"
    if {$children == 0} { 
	set leaf_json "leaf:true" 
	set icon "task"
    }

    

    append result "${indent_space}${indent}task:'[ns_quotehtml $name]',
${indent_space}${indent}duration:$content_length,
${indent_space}${indent}user:'$content_type',
${indent_space}${indent}$leaf_json,
${indent_space}${indent}iconCls:'$icon'\n"
}

# Finish a list of a certain level
while {$level > $min_level} {
    append result "$indent\}\]\n"
    incr level -1
    set indent ""
    for {set i $min_level} {$i < $level} {incr i} { append indent $indent_space }
}

set result "{\"text\":\".\"\n$result}"
ns_log Notice $result

doc_return 200 "text/plain" $result
